@@ -135,10 +135,15 @@ Create takes a hash of values and creates a row in the database:
   varchar(200) 'Type'.
   int(11) 'MaxValues'.
   varchar(255) 'Pattern'.
+  smallint(6) 'Repeated'.
   varchar(255) 'Description'.
   int(11) 'SortOrder'.
+  varchar(255) 'LookupType'.
   smallint(6) 'Disabled'.
 
+  'LookupType' is generally the result of either 
+  RT::Ticket->CustomFieldLookupType or RT::Transaction->CustomFieldLookupType
+
 =cut
 
 
@@ -286,7 +291,7 @@ sub LoadByName {
     # We only want one entry.
     $CFs->RowsPerPage(1);
     unless ($CFs->First) {
-        return(0, $self->loc('Custom field not found'));
+        return(0);
     }
     return($self->Load($CFs->First->id));
 
@@ -297,6 +302,7 @@ sub LoadByName {
 # {{{ Dealing with custom field values 
 
 =begin testing
+
 use_ok(RT::CustomField);
 ok(my $cf = RT::CustomField->new($RT::SystemUser));
 ok(my ($id, $msg)=  $cf->Create( Name => 'TestingCF',
@@ -446,6 +452,8 @@ sub Values {
 Returns a RT::ObjectCustomFieldValues object of this Field's values for TICKET.
 TICKET is a ticket id.
 
+This is deprecated -- use ValuesForObject instead.
+
 
 =cut
 
@@ -468,6 +476,8 @@ sub ValuesForTicket {
 
 Adds a custom field value for a ticket. Takes a param hash of Ticket and Content
 
+This is deprecated -- use AddValueForObject instead.
+
 =cut
 
 sub AddValueForTicket {
@@ -475,7 +485,7 @@ sub AddValueForTicket {
 	my %args = ( Ticket => undef,
                  Content => undef,
 		     @_ );
-    $RT::Logger->debug( ref($self) . " -> AddValueForTicket deprecated in favor of ValuesForObject"); 
+    $RT::Logger->debug( ref($self) . " -> AddValueForTicket deprecated in favor of AddValueForObject"); 
 
 
     my $ticket = RT::Ticket->new($self->CurrentUser);
@@ -493,6 +503,8 @@ sub AddValueForTicket {
 
 Adds a custom field value for a ticket. Takes a param hash of Ticket and Content
 
+This is deprecated -- use DeleteValueForObject instead.
+
 =cut
 
 sub DeleteValueForTicket {
@@ -501,7 +513,7 @@ sub DeleteValueForTicket {
                  Content => undef,
 		     @_ );
 
-    $RT::Logger->debug( ref($self) . " -> DeleteValueForTicket deprecated in favor of ValuesForObject"); 
+    $RT::Logger->debug( ref($self) . " -> DeleteValueForTicket deprecated in favor of DeleteValueForObject"); 
 
 
     my $ticket = RT::Ticket->new($self->CurrentUser);
@@ -560,6 +572,7 @@ Returns a localized human-readable version of the custom field type.
 If a custom field type is specified as the parameter, the friendly type for that type will be returned
 
 =cut
+
 sub FriendlyType {
     my $self = shift;
 
@@ -774,6 +787,7 @@ sub SetLookupType {
     }
     $self->SUPER::SetLookupType($lookup);
 }
+
 =head2 TypeComposite
 
 Returns a composite value composed of this object's type and maximum values
