@@ -43,6 +43,7 @@
 # those contributions and any derivatives thereof.
 # 
 # END BPS TAGGED BLOCK }}}
+
 =head1 NAME
 
   RT::Record - Base class for RT record objects
@@ -257,7 +258,7 @@ sub _Handle {
 
 # {{{ sub Create 
 
-=item  Create PARAMHASH
+=head2  Create PARAMHASH
 
 Takes a PARAMHASH of Column -> Value pairs.
 If any Column has a Validate$PARAMNAME subroutine defined and the 
@@ -376,10 +377,11 @@ sub LoadByCols {
                 $newhash{$key} = $hash{$key};
             }
             else {
-                my ($op, $val);
-                ($key, $op, $val) = $self->_Handle->_MakeClauseCaseInsensitive($key, '=', $hash{$key});
+                my ($op, $val, $func);
+                ($key, $op, $val, $func) = $self->_Handle->_MakeClauseCaseInsensitive($key, '=', $hash{$key});
                 $newhash{$key}->{operator} = $op;
                 $newhash{$key}->{value} = $val;
+                $newhash{$key}->{function} = $func;
             }
         }
 
@@ -925,6 +927,7 @@ sub Update {
         push @results, $self->loc( "$prefix [_1]", $label ) . ': '. $msg;
 
 =for loc
+
                                    "[_1] could not be set to [_2].",       # loc
                                    "That is already the current value",    # loc
                                    "No value sent to _Set!\n",             # loc
@@ -937,6 +940,7 @@ sub Update {
                                    "Couldn't find row",                    # loc
                                    "Missing a primary key?: [_1]",         # loc
                                    "Found Object",                         # loc
+
 =cut
 
     }
@@ -1052,6 +1056,12 @@ ok ($addid, $addmsg);
 ok (($addid, $addmsg) =$t1->AddLink( Type => 'DependsOn', Target => $t3->id));
 
 ok ($addid, $addmsg);
+my $link = RT::Link->new($RT::SystemUser);
+my ($rv, $msg) = $link->Load($addid);
+ok ($rv, $msg);
+ok ($link->LocalTarget == $t3->id, "Link LocalTarget is correct");
+ok ($link->LocalBase   == $t1->id, "Link LocalBase   is correct");
+
 ok ($t1->HasUnresolvedDependencies, "Ticket ".$t1->Id." has unresolved deps");
 ok (!$t1->HasUnresolvedDependencies( Type => 'blah' ), "Ticket ".$t1->Id." has no unresolved blahs");
 ok ($t1->HasUnresolvedDependencies( Type => 'approval' ), "Ticket ".$t1->Id." has unresolved approvals");
@@ -1300,7 +1310,7 @@ sub _AddLink {
     my $TransString =
       "Record $args{'Base'} $args{Type} record $args{'Target'}.";
 
-    return ( 1, $self->loc( "Link created ([_1])", $TransString ) );
+    return ( $linkid, $self->loc( "Link created ([_1])", $TransString ) );
 }
 
 # }}}
@@ -1487,29 +1497,30 @@ sub Transactions {
 
 sub CustomFields {
     my $self = shift;
-    my $cfs = RT::CustomFields->new( $self->CurrentUser );
-    $cfs->UnLimit;
+    my $cfs  = RT::CustomFields->new( $self->CurrentUser );
 
     # XXX handle multiple types properly
-	$cfs->LimitToLookupType($self->CustomFieldLookupType);
-	$cfs->LimitToGlobalOrObjectId($self->_LookupId($self->CustomFieldLookupType));
+    $cfs->LimitToLookupType( $self->CustomFieldLookupType );
+    $cfs->LimitToGlobalOrObjectId(
+        $self->_LookupId( $self->CustomFieldLookupType ) );
 
     return $cfs;
 }
 
-# TODO: This _only_ works for RT::Class classes. it doesn't work, for example, for RT::FM classes. 
+# TODO: This _only_ works for RT::Class classes. it doesn't work, for example, for RT::FM classes.
 
 sub _LookupId {
     my $self = shift;
     my $lookup = shift;
     my @classes = ($lookup =~ /RT::(\w+)-/g);
 
+    my $object = $self;
     foreach my $class (reverse @classes) {
 	my $method = "${class}Obj";
-	$self = $self->$method;
+	$object = $object->$method;
     }
 
-    return $self->Id;
+    return $object->Id;
 }
 
 
@@ -1536,7 +1547,7 @@ sub _LookupTypes {
 
 # {{{ AddCustomFieldValue
 
-=item AddCustomFieldValue { Field => FIELD, Value => VALUE }
+=head2 AddCustomFieldValue { Field => FIELD, Value => VALUE }
 
 VALUE should be a string.
 FIELD can be a CustomField object OR a CustomField ID.
@@ -1544,7 +1555,7 @@ FIELD can be a CustomField object OR a CustomField ID.
 
 Adds VALUE as a value of CustomField FIELD.  If this is a single-value custom field,
 deletes the old value. 
-If VALUE isn't a valid value for the custom field, returns 
+If VALUE is not a valid value for the custom field, returns 
 (0, 'Error message' ) otherwise, returns (1, 'Success Message')
 
 =cut
@@ -1563,22 +1574,10 @@ sub _AddCustomFieldValue {
         @_
     );
 
-   # {{{ Get a custom field object from the 'Field' parameter.
-   #
-   # XXX TODO: RT should be looking for a custom field for this object 
-   # with this name, if it's a name, rather than just "Load"
-   #
-    my $cf = RT::CustomField->new( $self->CurrentUser );
-    if ( UNIVERSAL::isa( $args{'Field'}, "RT::CustomField" ) ) {
-        $cf->Load( $args{'Field'}->id );
-    }
-    else {
-        $cf->Load( $args{'Field'} );
-    }
+    my $cf = $self->LoadCustomFieldByIdentifier($args{'Field'});
 
     unless ( $cf->Id ) {
-        return ( 0,
-            $self->loc( "Custom field [_1] not found", $args{'Field'} ) );
+        return ( 0, $self->loc( "Custom field [_1] not found", $args{'Field'} ) );
     }
 
     my $OCFs = $self->CustomFields;
@@ -1592,8 +1591,7 @@ sub _AddCustomFieldValue {
             )
         );
     }
-    # }}}
-# Load up a ObjectCustomFieldValues object for this custom field and this ticket
+    # Load up a ObjectCustomFieldValues object for this custom field and this ticket
     my $values = $cf->ValuesForObject($self);
 
     unless ( $cf->ValidateValue( $args{'Value'} ) ) {
@@ -1717,13 +1715,13 @@ sub _AddCustomFieldValue {
 
 # {{{ DeleteCustomFieldValue
 
-=item DeleteCustomFieldValue { Field => FIELD, Value => VALUE }
+=head2 DeleteCustomFieldValue { Field => FIELD, Value => VALUE }
 
 Deletes VALUE as a value of CustomField FIELD. 
 
 VALUE can be a string, a CustomFieldValue or a ObjectCustomFieldValue.
 
-If VALUE isn't a valid value for the custom field, returns 
+If VALUE is not a valid value for the custom field, returns 
 (0, 'Error message' ) otherwise, returns (1, 'Success Message')
 
 =cut
@@ -1737,18 +1735,11 @@ sub DeleteCustomFieldValue {
         @_
     );
 
-    my $cf = RT::CustomField->new( $self->CurrentUser );
-    if ( UNIVERSAL::isa( $args{'Field'}, "RT::CustomField" ) ) {
-        $cf->LoadById( $args{'Field'}->id );
-    }
-    else {
-        $cf->LoadById( $args{'Field'} );
-    }
+    my $cf = $self->LoadCustomFieldByIdentifier($args{'Field'});
 
     unless ( $cf->Id ) {
-        return ( 0, $self->loc("Custom field not found") );
+        return ( 0, $self->loc( "Custom field [_1] not found", $args{'Field'} ) );
     }
-
     my ( $val, $msg ) = $cf->DeleteValueForObject(
         Object  => $self,
         Id      => $args{'ValueId'},
@@ -1780,7 +1771,7 @@ sub DeleteCustomFieldValue {
 
 # {{{ FirstCustomFieldValue
 
-=item FirstCustomFieldValue FIELD
+=head2 FirstCustomFieldValue FIELD
 
 Return the content of the first value of CustomField FIELD for this ticket
 Takes a field id or name
@@ -1803,10 +1794,10 @@ sub FirstCustomFieldValue {
 
 # {{{ CustomFieldValues
 
-=item CustomFieldValues FIELD
+=head2 CustomFieldValues FIELD
 
 Return a ObjectCustomFieldValues object of all values of the CustomField whose 
-id or Name is FIELD for this ticket.  
+id or Name is FIELD for this record.
 
 Returns an RT::ObjectCustomFieldValues object
 
@@ -1816,41 +1807,53 @@ sub CustomFieldValues {
     my $self  = shift;
     my $field = shift;
 
-    my $cf_values = RT::ObjectCustomFieldValues->new( $self->CurrentUser );
+    if ($field) {
+        my $cf = $self->LoadCustomFieldByIdentifier($field);
 
-    # If we've been handed a value that contains at least one non-digit,
-    # it's a name.  Resolve it into an id.
-    #
-    if ( defined $field && $field =~ /\D+/ ) {
-
-        # Look up the field ID.
-        my $cfs = RT::CustomFields->new( $self->CurrentUser );
-        $cfs->LimitToGlobalOrObjectId( $self->Id() );
-        $cfs->LimitToLookupType($self->CustomFieldLookupType);
-        $cfs->Limit( FIELD => 'Name', OPERATOR => '=', VALUE => $field );
-
-        if ( $cfs->First ) {
-            $field = $cfs->First->id;
-        }
-        else {
-
-            #We didn't find a custom field, but they wanted one. let's
-            # return an empty
-            return ($cf_values);
+        # we were asked to search on a custom field we couldn't fine
+        unless ( $cf->id ) {
+            return RT::ObjectCustomFieldValues->new( $self->CurrentUser );
         }
+        return ( $cf->ValuesForObject($self) );
     }
 
-    # If we now have a custom field id, let's limit things down
-    # If we don't have a custom field ID, the $cf_values object will return
-    #  all values
-    $cf_values->LimitToCustomField($field) if ($field);
-    $cf_values->LimitToObject($self);
-    $cf_values->OrderBy( FIELD => 'id', ORDER => 'ASC' );
+    # we're not limiting to a specific custom field;
+    my $ocfs = RT::ObjectCustomFieldValues->new( $self->CurrentUser );
+    $ocfs->LimitToObject($self);
+    return $ocfs;
 
-
-    return ($cf_values);
 }
 
+=head2 CustomField IDENTIFER
+
+Find the custom field has id or name IDENTIFIER for this object.
+
+If no valid field is found, returns an empty RT::CustomField object.
+
+=cut
+
+sub LoadCustomFieldByIdentifier {
+    my $self = shift;
+    my $field = shift;
+    
+    my $cf = RT::CustomField->new($self->CurrentUser);
+
+    if ( UNIVERSAL::isa( $field, "RT::CustomField" ) ) {
+        $cf->LoadById( $field->id );
+    }
+    elsif ($field =~ /^\d+$/) {
+        $cf = RT::CustomField->new($self->CurrentUser);
+        $cf->Load($field); 
+    } else {
+
+        my $cfs = $self->CustomFields($self->CurrentUser);
+        $cfs->Limit(FIELD => 'Name', VALUE => $field);
+        $cf = $cfs->First || RT::CustomField->new($self->CurrentUser);
+    }
+    return $cf;
+}
+
+
 # }}}
 
 # }}}
